package com.example.what_the_fantasy.ui.navigations

import androidx.compose.runtime.Composable
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import com.example.what_the_fantasy.data.services.ServicesStub
import com.example.what_the_fantasy.ui.screens.AccueilPage
import com.example.what_the_fantasy.ui.screens.FavoritePage
import com.example.what_the_fantasy.ui.screens.LoginPage
import com.example.what_the_fantasy.ui.screens.ProfilPage
import com.example.what_the_fantasy.ui.screens.QuizEndPage
import com.example.what_the_fantasy.ui.screens.QuizMenu
import com.example.what_the_fantasy.ui.screens.QuizPage
import com.example.what_the_fantasy.ui.screens.QuotePage
import com.example.what_the_fantasy.ui.screens.SearchPage
import com.example.what_the_fantasy.ui.screens.SignUpPage
import com.example.what_the_fantasy.ui.screens.SubmitQuotePage



sealed class Destination(val route: String) {
    data object Login : Destination("Login")
    data object Accueil : Destination("Accueil")
    data object Favorite : Destination("Favorite")
    data object Profil : Destination("Profil/{userIndex}") {  // Ajout du paramètre userIndex
        fun createRoute(userIndex: Int) = "Profil/$userIndex"  // Fonction pour créer la route avec l'index
    }
    data object QuizMenu : Destination("QuizMenu")
    data object Quiz : Destination("Quiz")
    data object QuizEnd : Destination("QuizEnd/{idQuiz}/{pts}") {
        // Ajout paramètres idQuiz et pts
        fun createIdAndPts(idQuiz : Int, pts : Int) = "QuizEnd/$idQuiz/$pts"
    }
    data object Quote : Destination("Quote")
    data object Search : Destination("Search")
    data object SignUp : Destination("SignUp")
    data object SubmitQuote : Destination("SubmitQuote")
}

@Composable
fun AppNavigator() {
    val navController = rememberNavController()
    val services = ServicesStub() // A changer si l'on veut passer au service API
    NavHost(navController, startDestination = Destination.Login.route) {
        composable(Destination.Login.route) {
            LoginPage(
                navControllerSignUp = { navController.navigate(Destination.SignUp.route) },
                navControllerProfil = { userIndex ->
                    navController.navigate(Destination.Profil.createRoute(userIndex))  // Passe l'index à Profil
                },
                services
            )
        }
        composable(Destination.Accueil.route) { AccueilPage() }
        composable(Destination.Favorite.route) { FavoritePage() }
        composable(Destination.QuizMenu.route) {
            QuizMenu(
                navControllerQuiz = { navController.navigate(Destination.Quiz.route) }
            )
        }
        composable(Destination.Quiz.route) {
            QuizPage(
                navControllerQuizEnd = { idQuiz, pts ->
                    navController.navigate(Destination.QuizEnd.createIdAndPts(idQuiz, pts))
                },
                navControllerQuizMenu = { navController.navigate(Destination.QuizMenu.route) }
            )
        }
        composable(Destination.QuizEnd.route) { backStackEntry ->
            val idQuiz = backStackEntry.arguments?.getString("idQuiz")?.toInt() ?: 0
            val pts = backStackEntry.arguments?.getString("pts")?.toInt() ?: 0
            QuizEndPage(
                idQuiz,
                pts,
                navControllerQuizMenu = { navController.navigate(Destination.QuizMenu.route) }
            )
        }
        composable(Destination.Profil.route) {
            // Récupère l'index passé dans la route
            val userIndex = it.arguments?.getString("userIndex")?.toInt() ?: -1
            ProfilPage(index = userIndex, navController = navController, services)
        }
        composable(Destination.Quote.route) { QuotePage() }
        composable(Destination.Search.route) { SearchPage() }
        composable(Destination.SignUp.route) { SignUpPage(navController, services) }
        composable(Destination.SubmitQuote.route) { SubmitQuotePage() }
    }
}
